@@ -72,12 +72,16 @@ class WorkflowDagBuilder:
         #logging.debug(f" Upstream task ids: {task.upstream_task_ids}")
         execution_date = context['execution_date']
         dag_instance = context['dag']
+        task_status_list = []
         for each in upstream_ids:
-            operator_instance = dag_instance.get_task(each)
-            task_status = TaskInstance(operator_instance, execution_date).current_state()
-            #logging.debug(f" Status for upstream task {each} is {task_status}")
-            if task_status == "upstream_failed" or task_status == "skipped":
-                raise AirflowSkipException
+           operator_instance = dag_instance.get_task(each)
+           task_status = TaskInstance(operator_instance, execution_date).current_state()
+           #logging.debug(f" Status for upstream task {each} is {task_status}")
+           task_status_list.append(task_status)
+           #if task_status == "upstream_failed" or task_status == "skipped":
+           #    raise AirflowSkipException
+        if all(status == "upstream_failed" or status == "skipped" for status in task_status_list):
+           raise AirflowSkipException
 
 
     @staticmethod
