@@ -7,6 +7,11 @@ from typing import Any, Dict, Optional, List
 from airflow import DAG
 
 from datamorphairflow import utils
+from datamorphairflow.datamorph_constants import DATAMORPH_UI_PROPERTY, DATAMORPH_PROPERTY_OUTPUTTO, \
+    DATAMORPH_UI_PROPERTY_ID, DATAMORPH_PROPERTY_DEPENDSON, DATAMORPH_PROPERTY_WORKFLOW, DATAMORPH_PROPERTIES, \
+    DATAMORPH_PROPERTY_DESCRIPTION, DATAMORPH_PROPERTY_NAME, DATAMORPH_PROPERTY_NODETYPE, DATAMORPH_PROPERTY_TYPE, \
+    DATAMORPH_PROPERTY_DATAMORPHCONF, AIRFLOW_PROPERTY_DAG_ID, AIRFLOW_PROPERTY_DESC, DATAMORPH_PROPERTY_JOBPARAMS, \
+    DATAMORPH_JOBPARAMS_STICKYPARAMS, DATAMORPH_JOBPARAMS_WORKFLOWRUNTINE
 from datamorphairflow.helper_classes import WorkflowDAGNode, WorkflowDAG
 from datamorphairflow.workflow_dag_builder import WorkflowDagBuilder
 
@@ -54,7 +59,7 @@ class WorkflowDagFactory:
         # pylint: disable=consider-using-with
         try:
             config: Dict[str, Any] = utils.load_json_config_file(config_file_path=config_filepath)
-            #logging.debug(f" Config: {config}")
+            # logging.debug(f" Config: {config}")
 
         except Exception as err:
             raise Exception("Invalid Workflow DAG config file:", format(config_filepath)) from err
@@ -70,7 +75,7 @@ class WorkflowDagFactory:
         # pylint: disable=consider-using-with
         try:
             config: Dict[str, Any] = utils.load_json_config_file(s3key=s3key, s3bucket=s3bucket)
-            #logging.debug(f" Config: {config}")
+            # logging.debug(f" Config: {config}")
 
         except Exception as err:
             raise Exception("Invalid Workflow DAG config file:", format("s3://" + s3bucket + "/" + s3key)) from err
@@ -84,34 +89,33 @@ class WorkflowDagFactory:
 
         :returns: dict with default configuration to create dag
         """
-        config_elems = self.config["datamorphConf"]["properties"]["job_params"]
-        # utils.remove_keys(config_elems, ["substitutions"])
+        config_elems = self.config[DATAMORPH_PROPERTY_DATAMORPHCONF][DATAMORPH_PROPERTIES][DATAMORPH_PROPERTY_JOBPARAMS]
+        utils.remove_keys(config_elems, [DATAMORPH_JOBPARAMS_STICKYPARAMS, DATAMORPH_JOBPARAMS_WORKFLOWRUNTINE])
         return config_elems
 
-    def remove_datamorph_properties(self,properties: dict):
+    def remove_datamorph_properties(self, properties: dict):
         # remove DataMorph UI specific properties
-        properties = utils.remove_key(properties, "ui")
-        properties = utils.remove_key(properties,"outputTo")
-        properties = utils.remove_key(properties,"id")
-        properties = utils.remove_key(properties, "dependsOn")
+        properties = utils.remove_key(properties, DATAMORPH_UI_PROPERTY)
+        properties = utils.remove_key(properties, DATAMORPH_PROPERTY_OUTPUTTO)
+        properties = utils.remove_key(properties, DATAMORPH_UI_PROPERTY_ID)
+        properties = utils.remove_key(properties, DATAMORPH_PROPERTY_DEPENDSON)
         properties = utils.remove_key(properties, "aws_region")
         return properties
 
-
     def get_workflow_nodes(self) -> List[WorkflowDAGNode]:
         nodelist = []
         try:
-            workflow = self.config["workflow"]
+            workflow = self.config[DATAMORPH_PROPERTY_WORKFLOW]
             for node in ast.literal_eval(str(workflow)):
-                properties = node.get("properties")
-                description = node.get("description")
-                name = node.get('name')
-                type = node.get('type')
-                nodetype = node.get('nodeType')
+                properties = node.get(DATAMORPH_PROPERTIES)
+                description = node.get(DATAMORPH_PROPERTY_DESCRIPTION)
+                name = node.get(DATAMORPH_PROPERTY_NAME)
+                type = node.get(DATAMORPH_PROPERTY_TYPE)
+                nodetype = node.get(DATAMORPH_PROPERTY_NODETYPE)
                 # all nodes may not have depends on
-                dependson = properties.get("dependsOn", "")
+                dependson = properties.get(DATAMORPH_PROPERTY_DEPENDSON, "")
                 # remove DataMorph specific properties
-                filtered_properties= self.remove_datamorph_properties(properties)
+                filtered_properties = self.remove_datamorph_properties(properties)
                 # only if node type is action or trigger, add to the list of dag nodes.
                 # Any new nodetype for dag should be included here
                 if nodetype in ["action", "trigger"]:
@@ -131,11 +135,11 @@ class WorkflowDagFactory:
         :return: DAG
         """
         workflow_node_list = self.get_workflow_nodes()
-        dag_name = self.config["datamorphConf"]["name"]
-        dag_desc = self.config["datamorphConf"]["description"]
+        dag_name = self.config[DATAMORPH_PROPERTY_DATAMORPHCONF][DATAMORPH_PROPERTY_NAME]
+        dag_desc = self.config[DATAMORPH_PROPERTY_DATAMORPHCONF][DATAMORPH_PROPERTY_DESCRIPTION]
         default_config = self.get_default_config()
-        default_config["dag_id"] = dag_name
-        default_config["description"] = dag_desc
+        default_config[AIRFLOW_PROPERTY_DAG_ID] = dag_name
+        default_config[AIRFLOW_PROPERTY_DESC] = dag_desc
         workflow_dag_builder: WorkflowDagBuilder = WorkflowDagBuilder(
             dag_name=dag_name,
             dag_config=default_config,
